@@ -628,8 +628,14 @@ bool CSharpImport::parseEnumDeclaration()
     UMLEnum *enumType = static_cast<UMLEnum*>(ns);
     skipStmt(QLatin1String("{"));
     while (m_srcIndex < m_source.count() - 1 && advance() != QLatin1String("}")) {
-        Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex]);
         QString next = advance();
+        if (next == QLatin1String("=")) {
+            next = advance();
+            Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex - 2], QString(), m_source[m_srcIndex]);
+            next = advance();
+        } else {
+            Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex - 1]);
+        }
         if (next == QLatin1String("{") || next == QLatin1String("(")) {
             if (! skipToClosing(next[0]))
                 return false;
@@ -686,13 +692,14 @@ bool CSharpImport::parseClassDeclaration(const QString& keyword)
     log(keyword + QLatin1Char(' ') + name);
     UMLObject *ns = Import_Utils::createUMLObject(ot, name, currentScope(), m_comment);
     pushScope(m_klass = static_cast<UMLClassifier*>(ns));
-    m_klass->setAbstract(m_isAbstract);
     m_klass->setStatic(m_isStatic);
     m_klass->setVisibilityCmd(m_currentAccess);
     // The UMLObject found by createUMLObject might originally have been created as a
     // placeholder with a type of class but if is really an interface, then we need to
     // change it.
     m_klass->setBaseType(ot);
+    // TODO: UMLClassifier::setBaseType() resets abstract flag
+    m_klass->setAbstract(m_isAbstract);
     m_isAbstract = m_isStatic = false;
     // if no modifier is specified in an interface, then it means public
     if (m_klass->isInterface()) {
