@@ -25,10 +25,12 @@
 #include "umldoc.h"
 
 #include <kcombobox.h>
+#if QT_VERSION < 0x050000
 #include <kdialogbuttonbox.h>
+#endif
 #include <klineedit.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include <QGroupBox>
 #include <QHBoxLayout>
@@ -43,19 +45,11 @@
  *  @param pUniqueConstraint The Unique Constraint to show the properties of.
  */
 UMLUniqueConstraintDialog::UMLUniqueConstraintDialog(QWidget* parent, UMLUniqueConstraint* pUniqueConstraint)
-  : KDialog(parent),
-    m_pUniqueConstraint(pUniqueConstraint),
-    m_doc(UMLApp::app()->document())
+  : SinglePageDialogBase(parent, true),
+    m_pUniqueConstraint(pUniqueConstraint)
 {
     setCaption(i18n("Unique Constraint Properties"));
-    setButtons(Help | Ok | Apply | Cancel);
-    setDefaultButton(Ok);
-    setModal(true);
-    showButtonSeparator(true);
-
     setupDialog();
-    connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
-    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
 }
 
 /**
@@ -116,11 +110,19 @@ void UMLUniqueConstraintDialog::setupDialog()
     comboButtonHBoxLayout->addWidget(m_pAttributeCB);
 
     //the action buttons
+#if QT_VERSION >= 0x050000
+    QDialogButtonBox* buttonBox = new QDialogButtonBox(m_pAttributeListGB);
+    m_pAddPB = buttonBox->addButton(i18n("&Add"), QDialogButtonBox::ActionRole);
+    connect(m_pAddPB, SIGNAL(clicked()), this, SLOT(slotAddAttribute()));
+    m_pRemovePB = buttonBox->addButton(i18n("&Delete"), QDialogButtonBox::ActionRole);
+    connect(m_pRemovePB, SIGNAL(clicked()), this, SLOT(slotDeleteAttribute()));
+#else
     KDialogButtonBox* buttonBox = new KDialogButtonBox(m_pAttributeListGB);
     m_pAddPB = buttonBox->addButton(i18n("&Add"), KDialogButtonBox::ActionRole, this,
                           SLOT(slotAddAttribute()));
     m_pRemovePB = buttonBox->addButton(i18n("&Delete"), KDialogButtonBox::ActionRole, this,
                           SLOT(slotDeleteAttribute()));
+#endif
 
     comboButtonHBoxLayout->addWidget(buttonBox);
 
@@ -221,24 +223,6 @@ void UMLUniqueConstraintDialog::slotDeleteAttribute()
     slotResetWidgetState();
 }
 
-/**
- * Used when the Apply Button is clicked.
- */
-void UMLUniqueConstraintDialog::slotApply()
-{
-    apply();
-}
-
-/**
- * Used when the OK button is clicked.  Calls apply().
- */
-void UMLUniqueConstraintDialog::slotOk()
-{
-    if (apply()) {
-        accept();
-    }
-}
-
 /**
  * Apply changes.
  */
@@ -291,5 +275,4 @@ void UMLUniqueConstraintDialog::slotResetWidgetState()
     }
 }
 
-#include "umluniqueconstraintdialog.moc"
 
