@@ -19,6 +19,7 @@
 #include <QGraphicsObject>
 #include <QObject>
 #include <QPainter>
+#include <QPointer>
 
 // forward declarations
 class QAction;
@@ -40,7 +41,8 @@ class WidgetBase : public QGraphicsObject
 public:
     enum WidgetType
     {
-        wt_UMLWidget = 300,         // does not have UMLObject representation
+        wt_MIN = 299,               // lower bounds check value
+        wt_UMLWidget,               // does not have UMLObject representation
         wt_Actor,                   // has UMLObject representation
         wt_UseCase,                 // has UMLObject representation
         wt_Class,                   // has UMLObject representation
@@ -69,7 +71,8 @@ public:
         wt_ObjectNode,
         wt_Region,
         wt_Category,                // has UMLObject representation
-        wt_Port                     // has UMLObject representation
+        wt_Port,                    // has UMLObject representation
+        wt_MAX                      // upper bounds check value
     };
 
     static QString toString(WidgetType wt);
@@ -85,6 +88,7 @@ public:
     void setID(Uml::ID::Type id);
 
     WidgetType baseType() const;
+    void setBaseType(const WidgetType& baseType);
     QLatin1String baseTypeStr() const;
 
     virtual void setSelected(bool select);
@@ -155,9 +159,11 @@ public Q_SLOTS:
 protected:
     virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent *event);
 
+private:
     WidgetType  m_baseType;  ///< Type of widget.
+protected:
     UMLScene   *m_scene;
-    UMLObject  *m_umlObject;
+    QPointer<UMLObject> m_umlObject;
     QString     m_Doc;   ///< Only used if m_umlObject is not set.
     QString     m_Text;
     QRectF      m_rect;  ///< widget size
