@@ -11,7 +11,9 @@
 #ifndef UMBRELLO_VERSION_H
 #define UMBRELLO_VERSION_H
 
+#if QT_VERSION < 0x050000
 #include <kdeversion.h>
+#endif
 
 inline QByteArray umbrelloVersion()
 {
@@ -27,6 +29,10 @@ inline QByteArray umbrelloVersion()
 }
 
 // Update this version when changing the XMI file format
-#define XMI_FILE_VERSION "1.6.9"
+#ifdef ENABLE_WIDGET_SHOW_DOC
+#define XMI_FILE_VERSION "1.6.11"
+#else
+#define XMI_FILE_VERSION "1.6.10"
+#endif
 
 #endif
